==> jangaroo-sdk-0.9.3.zip: joo/classes/js/Element.js <==
joo.classLoader.prepare("package js",/* {*/

"public class Element extends js.Node",2,function($$private){;return[ 

  "public native function get id"/*() : String*/,



  "public native function set id"/*(id : String) : void*/,



  "public native function get tagName"/*() : String*/,



  "public native function get ownerDocument"/*() : Document*/,



  "public native function get contentWindow"/*() : Window*/,



  "public native function get innerHTML"/*() : String*/,



  "public native function set innerHTML"/*(s : String) : void*/,



  "public native function get outerHTML"/*() : String*/,



  "public native function set outerHTML"/*(s : String) : void*/,



  "public native function get style"/*() : Style*/,



  "public native function get runtimeStyle"/*() : Style*/,



  "public native function get filters"/*() : Collection*/, // IE only



  "public native function get offsetLeft"/*() : Number*/,



  "public native function get offsetTop"/*() : Number*/,



  "public native function get offsetWidth"/*() : Number*/,



  "public native function get offsetHeight"/*() : Number*/,



  "public native function get offsetParent"/*() : Element*/,



  "public native function get clientWidth"/*() : Number*/,



  "public native function get clientHeight"/*() : Number*/,



  "public native function get className"/*() : String*/,



  "public native function set className"/*(s : String) : void*/,



  "public native function get scrollLeft"/*() : Number*/,



  "public native function set scrollLeft"/*(value : Number) : void*/,



  "public native function get scrollTop"/*()  : Number*/,



  "public native function set scrollTop"/*(value : Number) : void*/,



  "public native function focus"/*() : void*/,



  "public native function select"/*() : void*/,



  "public native function get attributes"/*() : Collection*/,



  "public native function mergeAttributes"/*(withElem : Element, copyId : Boolean = true) : void*/,



  "public native function get htmlFor"/*() : String*/,



  "public native function set htmlFor"/*(htmlFor : String) : void*/,



  "public native function get scopeName"/*() : String*/,   // IE only



  "public native function getAttribute"/*(name : String, iFlags:int = 0) : Object*/, // iFlags: IE only



  "public native function removeAttribute"/*(name : String) : void*/,



  "public native function get title"/*() : String*/,



  "public native function get defaultChecked"/*() : String*/,



  "public native function set defaultChecked"/*(checked : String) : void*/,



  "public native function get tBodies"/*() : Array*/,



  "public native function get rows"/*() : Array*/,



  "public native function get cells"/*() : Array*/,



  "public native function get name"/*() : String*/,



  "public native function set name"/*(name : String) : void*/,



  "public native function get value"/*() : String*/,



  "public native function set value"/*(value : String) : void*/,



  "public native function get defaultValue"/*() : String*/,



  "public native function set defaultValue"/*(value : String) : void*/,



  "public native function get checked"/*() : Boolean*/,



  "public native function set checked"/*(checked : Boolean) : void*/,



  "public native function get disabled"/*() : Boolean*/,

  "public native function set disabled"/*(value : Boolean) : void*/,


  "public native function get selectedIndex"/*() : Number*/, // <select>

  "public native function set selectedIndex"/*(value : Number) : void*/, // <select>

  "public native function get href"/*() : String*/, // <a>, <link>

  "public native function set href"/*(href : String) : void*/, // <a>, <link>

  "public native function get target"/*() : String*/, // <a>

  "public native function set target"/*(target : String) : void*/, // <a>

  "public native function get colSpan"/*() : Number*/, // <th>, <td>

  "public native function set colSpan"/*(span : Number) : void*/, // <th>, <td>

  "public native function get rowSpan"/*() : Number*/, // <th>, <td>

  "public native function set rowSpan"/*(span : Number) : void*/, // <th>, <td>

  "public native function get selectionStart"/*() : Number*/, // <input type="text">, <textarea>

  "public native function set selectionStart"/*(start : Number) : void*/,  // <input type="text">, <textarea>

  "public native function get selectionEnd"/*() : Number*/, // <input type="text">, <textarea>

  "public native function set selectionEnd"/*(end : Number) : void*/, // <input type="text">, <textarea>

  "public native function scrollIntoView"/*(alignWithTop : Boolean = true) : void*/,

  "public native function createTextRange"/*() : TextRange*/, // IE only

  "public native function createControlRange"/*() : ControlRange*/, // IE only

];},[],["js.Node"], "0.8.0", "0.9.3"

);

==> jangaroo-sdk-0.9.13.zip: joo/classes/js/Element.js <==
joo.classLoader.prepare("package js",/* {*/

"public class Element extends js.Node",2,function($$private){var $1=js;return[ 

  "public native function get id"/*() : String*/,



  "public native function set id"/*(id : String) : void*/,



  "public native function get tagName"/*() : String*/,



  "public native function get ownerDocument"/*() : Document*/,



  "public native function get contentWindow"/*() : Window*/,



  "public native function get innerHTML"/*() : String*/,



  "public native function set innerHTML"/*(s : String) : void*/,



  "public native function get outerHTML"/*() : String*/,



  "public native function set outerHTML"/*(s : String) : void*/,



  "public native function get style"/*() : Style*/,



  "public native function get runtimeStyle"/*() : Style*/,



  "public native function get filters"/*() : Collection*/, // IE only



  "public native function get offsetLeft"/*() : Number*/,



  "public native function get offsetTop"/*() : Number*/,



  "public native function get offsetWidth"/*() : Number*/,



  "public native function get offsetHeight"/*() : Number*/,



  "public native function get offsetParent"/*() : Element*/,



  "public native function get clientWidth"/*() : Number*/,



  "public native function get clientHeight"/*() : Number*/,



  "public native function get className"/*() : String*/,



  "public native function set className"/*(s : String) : void*/,



  "public native function get scrollLeft"/*() : Number*/,



  "public native function set scrollLeft"/*(value : Number) : void*/,



  "public native function get scrollTop"/*()  : Number*/,



  "public native function set scrollTop"/*(value : Number) : void*/,



  "public native function focus"/*() : void*/,



  "public native function select"/*() : void*/,



  "public native function get attributes"/*() : Collection*/,



  "public native function mergeAttributes"/*(withElem : Element, copyId : Boolean = true) : void*/,



  "public native function get htmlFor"/*() : String*/,



  "public native function set htmlFor"/*(htmlFor : String) : void*/,



  "public native function get scopeName"/*() : String*/,   // IE only



  "public native function getAttribute"/*(name : String, iFlags:int = 0) : Object*/, // iFlags: IE only



  "public native function removeAttribute"/*(name : String) : void*/,



  "public native function get title"/*() : String*/,



  "public native function get defaultChecked"/*() : String*/,



  "public native function set defaultChecked"/*(checked : String) : void*/,



  "public native function get tBodies"/*() : Array*/,



  "public native function get rows"/*() : Array*/,



  "public native function get cells"/*() : Array*/,



  "public native function get name"/*() : String*/,



  "public native function set name"/*(name : String) : void*/,



  "public native function get value"/*() : String*/,



  "public native function set value"/*(value : String) : void*/,



  "public native function get defaultValue"/*() : String*/,



  "public native function set defaultValue"/*(value : String) : void*/,



  "public native function get checked"/*() : Boolean*/,



  "public native function set checked"/*(checked : Boolean) : void*/,



  "public native function get disabled"/*() : Boolean*/,

  "public native function set disabled"/*(value : Boolean) : void*/,


  "public native function get selectedIndex"/*() : Number*/, // <select>

  "public native function set selectedIndex"/*(value : Number) : void*/, // <select>

  "public native function get href"/*() : String*/, // <a>, <link>

  "public native function set href"/*(href : String) : void*/, // <a>, <link>

  "public native function get target"/*() : String*/, // <a>

  "public native function set target"/*(target : String) : void*/, // <a>

  "public native function get colSpan"/*() : Number*/, // <th>, <td>

  "public native function set colSpan"/*(span : Number) : void*/, // <th>, <td>

  "public native function get rowSpan"/*() : Number*/, // <th>, <td>

  "public native function set rowSpan"/*(span : Number) : void*/, // <th>, <td>

  "public native function get selectionStart"/*() : Number*/, // <input type="text">, <textarea>

  "public native function set selectionStart"/*(start : Number) : void*/,  // <input type="text">, <textarea>

  "public native function get selectionEnd"/*() : Number*/, // <input type="text">, <textarea>

  "public native function set selectionEnd"/*(end : Number) : void*/, // <input type="text">, <textarea>

  "public native function scrollIntoView"/*(alignWithTop : Boolean = true) : void*/,

  "public native function createTextRange"/*() : TextRange*/, // IE only

  "public native function createControlRange"/*() : ControlRange*/, // IE only

undefined];},[],["js.Node"], "0.8.0", "0.9.12"

);
